model

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 23, 2025 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type StatisticPoint

type StatisticPoint struct {
	Start  time.Time
	End    time.Time
	Dur    time.Duration
	Visits int64
}

StatisticPoint is a structure that holds data of an interval of time, and the visits in that interval

func (*StatisticPoint) Encode

func (point *StatisticPoint) Encode() *pb.StatisticPoint

Encode converts a StatisticPoint into a *pb.StatisticPoint

Jump to